@@ -16,18 +16,18 @@
 from collections import OrderedDict
 import os
 import re
-from typing import Dict, Optional, Sequence, Tuple, Type, Union
-import pkg_resources
+from typing import Dict, Mapping, Optional, Sequence, Tuple, Type, Union
 
 from google.api_core import client_options as client_options_lib
 from google.api_core import exceptions as core_exceptions
 from google.api_core import gapic_v1
 from google.api_core import retry as retries
 from google.auth import credentials as ga_credentials  # type: ignore
+from google.auth.exceptions import MutualTLSChannelError  # type: ignore
 from google.auth.transport import mtls  # type: ignore
 from google.auth.transport.grpc import SslCredentials  # type: ignore
-from google.auth.exceptions import MutualTLSChannelError  # type: ignore
 from google.oauth2 import service_account  # type: ignore
+import pkg_resources
 
 try:
     OptionalRetry = Union[retries.Retry, gapic_v1.method._MethodDefault]
@@ -36,7 +36,8 @@ except AttributeError:  # pragma: NO COVER
 
 from google.cloud.dataflow_v1beta3.services.messages_v1_beta3 import pagers
 from google.cloud.dataflow_v1beta3.types import messages
-from .transports.base import MessagesV1Beta3Transport, DEFAULT_CLIENT_INFO
+
+from .transports.base import DEFAULT_CLIENT_INFO, MessagesV1Beta3Transport
 from .transports.grpc import MessagesV1Beta3GrpcTransport
 from .transports.grpc_asyncio import MessagesV1Beta3GrpcAsyncIOTransport
 
@@ -55,7 +56,10 @@ class MessagesV1Beta3ClientMeta(type):
     _transport_registry["grpc"] = MessagesV1Beta3GrpcTransport
     _transport_registry["grpc_asyncio"] = MessagesV1Beta3GrpcAsyncIOTransport
 
-    def get_transport_class(cls, label: str = None,) -> Type[MessagesV1Beta3Transport]:
+    def get_transport_class(
+        cls,
+        label: str = None,
+    ) -> Type[MessagesV1Beta3Transport]:
         """Returns an appropriate transport class.
 
         Args:
@@ -162,7 +166,9 @@ class MessagesV1Beta3Client(metaclass=MessagesV1Beta3ClientMeta):
         return self._transport
 
     @staticmethod
-    def common_billing_account_path(billing_account: str,) -> str:
+    def common_billing_account_path(
+        billing_account: str,
+    ) -> str:
         """Returns a fully-qualified billing_account string."""
         return "billingAccounts/{billing_account}".format(
             billing_account=billing_account,
@@ -175,9 +181,13 @@ class MessagesV1Beta3Client(metaclass=MessagesV1Beta3ClientMeta):
         return m.groupdict() if m else {}
 
     @staticmethod
-    def common_folder_path(folder: str,) -> str:
+    def common_folder_path(
+        folder: str,
+    ) -> str:
         """Returns a fully-qualified folder string."""
-        return "folders/{folder}".format(folder=folder,)
+        return "folders/{folder}".format(
+            folder=folder,
+        )
 
     @staticmethod
     def parse_common_folder_path(path: str) -> Dict[str, str]:
@@ -186,9 +196,13 @@ class MessagesV1Beta3Client(metaclass=MessagesV1Beta3ClientMeta):
         return m.groupdict() if m else {}
 
     @staticmethod
-    def common_organization_path(organization: str,) -> str:
+    def common_organization_path(
+        organization: str,
+    ) -> str:
         """Returns a fully-qualified organization string."""
-        return "organizations/{organization}".format(organization=organization,)
+        return "organizations/{organization}".format(
+            organization=organization,
+        )
 
     @staticmethod
     def parse_common_organization_path(path: str) -> Dict[str, str]:
@@ -197,9 +211,13 @@ class MessagesV1Beta3Client(metaclass=MessagesV1Beta3ClientMeta):
         return m.groupdict() if m else {}
 
     @staticmethod
-    def common_project_path(project: str,) -> str:
+    def common_project_path(
+        project: str,
+    ) -> str:
         """Returns a fully-qualified project string."""
-        return "projects/{project}".format(project=project,)
+        return "projects/{project}".format(
+            project=project,
+        )
 
     @staticmethod
     def parse_common_project_path(path: str) -> Dict[str, str]:
@@ -208,10 +226,14 @@ class MessagesV1Beta3Client(metaclass=MessagesV1Beta3ClientMeta):
         return m.groupdict() if m else {}
 
     @staticmethod
-    def common_location_path(project: str, location: str,) -> str:
+    def common_location_path(
+        project: str,
+        location: str,
+    ) -> str:
         """Returns a fully-qualified location string."""
         return "projects/{project}/locations/{location}".format(
-            project=project, location=location,
+            project=project,
+            location=location,
         )
 
     @staticmethod
@@ -403,7 +425,6 @@ class MessagesV1Beta3Client(metaclass=MessagesV1Beta3ClientMeta):
         can only request the status of jobs that are running in
         ``us-central1``.
 
-
         .. code-block:: python
 
             from google.cloud import dataflow_v1beta3
@@ -457,13 +478,33 @@ class MessagesV1Beta3Client(metaclass=MessagesV1Beta3ClientMeta):
         # and friendly error handling.
         rpc = self._transport._wrapped_methods[self._transport.list_job_messages]
 
+        # Certain fields should be provided within the metadata header;
+        # add these here.
+        metadata = tuple(metadata) + (
+            gapic_v1.routing_header.to_grpc_metadata(
+                (
+                    ("project_id", request.project_id),
+                    ("location", request.location),
+                    ("job_id", request.job_id),
+                )
+            ),
+        )
+
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # This method is paged; wrap the response in a pager, which provides
         # an `__iter__` convenience method.
         response = pagers.ListJobMessagesPager(
-            method=rpc, request=request, response=response, metadata=metadata,
+            method=rpc,
+            request=request,
+            response=response,
+            metadata=metadata,
         )
 
         # Done; return the response.
