@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2020 Google LLC
+# Copyright 2022 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -13,13 +13,12 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-import proto  # type: ignore
-
-from google.cloud.dataflow_v1beta3.types import environment as gd_environment
 from google.protobuf import duration_pb2  # type: ignore
 from google.protobuf import struct_pb2  # type: ignore
 from google.protobuf import timestamp_pb2  # type: ignore
+import proto  # type: ignore
 
+from google.cloud.dataflow_v1beta3.types import environment as gd_environment
 
 __protobuf__ = proto.module(
     package="google.dataflow.v1beta3",
@@ -101,7 +100,6 @@ class JobView(proto.Enum):
 
 class Job(proto.Message):
     r"""Defines a job to be run by the Cloud Dataflow service.
-    nextID: 26
 
     Attributes:
         id (str):
@@ -172,7 +170,7 @@ class Job(proto.Message):
             When sending a ``CreateJobRequest``, you can update a job by
             specifying it here. The job named here is stopped, and its
             intermediate state is transferred to this job.
-        transform_name_mapping (Sequence[google.cloud.dataflow_v1beta3.types.Job.TransformNameMappingEntry]):
+        transform_name_mapping (Mapping[str, str]):
             The map of transform name prefixes of the job
             to be replaced to the corresponding name
             prefixes of the new job.
@@ -205,7 +203,7 @@ class Job(proto.Message):
 
                storage.googleapis.com/{bucket}/{object}
                bucket.storage.googleapis.com/{object}
-        labels (Sequence[google.cloud.dataflow_v1beta3.types.Job.LabelsEntry]):
+        labels (Mapping[str, str]):
             User-defined labels for this job.
 
             The labels map can contain no more than 64 entries. Entries
@@ -253,41 +251,120 @@ class Job(proto.Message):
             if it is set in any requests.
     """
 
-    id = proto.Field(proto.STRING, number=1,)
-    project_id = proto.Field(proto.STRING, number=2,)
-    name = proto.Field(proto.STRING, number=3,)
-    type_ = proto.Field(proto.ENUM, number=4, enum=gd_environment.JobType,)
+    id = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    project_id = proto.Field(
+        proto.STRING,
+        number=2,
+    )
+    name = proto.Field(
+        proto.STRING,
+        number=3,
+    )
+    type_ = proto.Field(
+        proto.ENUM,
+        number=4,
+        enum=gd_environment.JobType,
+    )
     environment = proto.Field(
-        proto.MESSAGE, number=5, message=gd_environment.Environment,
+        proto.MESSAGE,
+        number=5,
+        message=gd_environment.Environment,
+    )
+    steps = proto.RepeatedField(
+        proto.MESSAGE,
+        number=6,
+        message="Step",
+    )
+    steps_location = proto.Field(
+        proto.STRING,
+        number=24,
+    )
+    current_state = proto.Field(
+        proto.ENUM,
+        number=7,
+        enum="JobState",
     )
-    steps = proto.RepeatedField(proto.MESSAGE, number=6, message="Step",)
-    steps_location = proto.Field(proto.STRING, number=24,)
-    current_state = proto.Field(proto.ENUM, number=7, enum="JobState",)
     current_state_time = proto.Field(
-        proto.MESSAGE, number=8, message=timestamp_pb2.Timestamp,
+        proto.MESSAGE,
+        number=8,
+        message=timestamp_pb2.Timestamp,
+    )
+    requested_state = proto.Field(
+        proto.ENUM,
+        number=9,
+        enum="JobState",
+    )
+    execution_info = proto.Field(
+        proto.MESSAGE,
+        number=10,
+        message="JobExecutionInfo",
     )
-    requested_state = proto.Field(proto.ENUM, number=9, enum="JobState",)
-    execution_info = proto.Field(proto.MESSAGE, number=10, message="JobExecutionInfo",)
     create_time = proto.Field(
-        proto.MESSAGE, number=11, message=timestamp_pb2.Timestamp,
+        proto.MESSAGE,
+        number=11,
+        message=timestamp_pb2.Timestamp,
+    )
+    replace_job_id = proto.Field(
+        proto.STRING,
+        number=12,
+    )
+    transform_name_mapping = proto.MapField(
+        proto.STRING,
+        proto.STRING,
+        number=13,
+    )
+    client_request_id = proto.Field(
+        proto.STRING,
+        number=14,
+    )
+    replaced_by_job_id = proto.Field(
+        proto.STRING,
+        number=15,
+    )
+    temp_files = proto.RepeatedField(
+        proto.STRING,
+        number=16,
+    )
+    labels = proto.MapField(
+        proto.STRING,
+        proto.STRING,
+        number=17,
+    )
+    location = proto.Field(
+        proto.STRING,
+        number=18,
     )
-    replace_job_id = proto.Field(proto.STRING, number=12,)
-    transform_name_mapping = proto.MapField(proto.STRING, proto.STRING, number=13,)
-    client_request_id = proto.Field(proto.STRING, number=14,)
-    replaced_by_job_id = proto.Field(proto.STRING, number=15,)
-    temp_files = proto.RepeatedField(proto.STRING, number=16,)
-    labels = proto.MapField(proto.STRING, proto.STRING, number=17,)
-    location = proto.Field(proto.STRING, number=18,)
     pipeline_description = proto.Field(
-        proto.MESSAGE, number=19, message="PipelineDescription",
+        proto.MESSAGE,
+        number=19,
+        message="PipelineDescription",
     )
     stage_states = proto.RepeatedField(
-        proto.MESSAGE, number=20, message="ExecutionStageState",
+        proto.MESSAGE,
+        number=20,
+        message="ExecutionStageState",
+    )
+    job_metadata = proto.Field(
+        proto.MESSAGE,
+        number=21,
+        message="JobMetadata",
+    )
+    start_time = proto.Field(
+        proto.MESSAGE,
+        number=22,
+        message=timestamp_pb2.Timestamp,
+    )
+    created_from_snapshot_id = proto.Field(
+        proto.STRING,
+        number=23,
+    )
+    satisfies_pzs = proto.Field(
+        proto.BOOL,
+        number=25,
     )
-    job_metadata = proto.Field(proto.MESSAGE, number=21, message="JobMetadata",)
-    start_time = proto.Field(proto.MESSAGE, number=22, message=timestamp_pb2.Timestamp,)
-    created_from_snapshot_id = proto.Field(proto.STRING, number=23,)
-    satisfies_pzs = proto.Field(proto.BOOL, number=25,)
 
 
 class DatastoreIODetails(proto.Message):
@@ -300,8 +377,14 @@ class DatastoreIODetails(proto.Message):
             ProjectId accessed in the connection.
     """
 
-    namespace = proto.Field(proto.STRING, number=1,)
-    project_id = proto.Field(proto.STRING, number=2,)
+    namespace = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    project_id = proto.Field(
+        proto.STRING,
+        number=2,
+    )
 
 
 class PubSubIODetails(proto.Message):
@@ -314,8 +397,14 @@ class PubSubIODetails(proto.Message):
             Subscription used in the connection.
     """
 
-    topic = proto.Field(proto.STRING, number=1,)
-    subscription = proto.Field(proto.STRING, number=2,)
+    topic = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    subscription = proto.Field(
+        proto.STRING,
+        number=2,
+    )
 
 
 class FileIODetails(proto.Message):
@@ -327,11 +416,14 @@ class FileIODetails(proto.Message):
             connector.
     """
 
-    file_pattern = proto.Field(proto.STRING, number=1,)
+    file_pattern = proto.Field(
+        proto.STRING,
+        number=1,
+    )
 
 
 class BigTableIODetails(proto.Message):
-    r"""Metadata for a Cloud BigTable connector used by the job.
+    r"""Metadata for a Cloud Bigtable connector used by the job.
 
     Attributes:
         project_id (str):
@@ -342,9 +434,18 @@ class BigTableIODetails(proto.Message):
             TableId accessed in the connection.
     """
 
-    project_id = proto.Field(proto.STRING, number=1,)
-    instance_id = proto.Field(proto.STRING, number=2,)
-    table_id = proto.Field(proto.STRING, number=3,)
+    project_id = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    instance_id = proto.Field(
+        proto.STRING,
+        number=2,
+    )
+    table_id = proto.Field(
+        proto.STRING,
+        number=3,
+    )
 
 
 class BigQueryIODetails(proto.Message):
@@ -361,10 +462,22 @@ class BigQueryIODetails(proto.Message):
             Query used to access data in the connection.
     """
 
-    table = proto.Field(proto.STRING, number=1,)
-    dataset = proto.Field(proto.STRING, number=2,)
-    project_id = proto.Field(proto.STRING, number=3,)
-    query = proto.Field(proto.STRING, number=4,)
+    table = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    dataset = proto.Field(
+        proto.STRING,
+        number=2,
+    )
+    project_id = proto.Field(
+        proto.STRING,
+        number=3,
+    )
+    query = proto.Field(
+        proto.STRING,
+        number=4,
+    )
 
 
 class SpannerIODetails(proto.Message):
@@ -379,9 +492,18 @@ class SpannerIODetails(proto.Message):
             DatabaseId accessed in the connection.
     """
 
-    project_id = proto.Field(proto.STRING, number=1,)
-    instance_id = proto.Field(proto.STRING, number=2,)
-    database_id = proto.Field(proto.STRING, number=3,)
+    project_id = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    instance_id = proto.Field(
+        proto.STRING,
+        number=2,
+    )
+    database_id = proto.Field(
+        proto.STRING,
+        number=3,
+    )
 
 
 class SdkVersion(proto.Message):
@@ -405,9 +527,19 @@ class SdkVersion(proto.Message):
         DEPRECATED = 3
         UNSUPPORTED = 4
 
-    version = proto.Field(proto.STRING, number=1,)
-    version_display_name = proto.Field(proto.STRING, number=2,)
-    sdk_support_status = proto.Field(proto.ENUM, number=3, enum=SdkSupportStatus,)
+    version = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    version_display_name = proto.Field(
+        proto.STRING,
+        number=2,
+    )
+    sdk_support_status = proto.Field(
+        proto.ENUM,
+        number=3,
+        enum=SdkSupportStatus,
+    )
 
 
 class JobMetadata(proto.Message):
@@ -424,11 +556,11 @@ class JobMetadata(proto.Message):
             Identification of a BigQuery source used in
             the Dataflow job.
         big_table_details (Sequence[google.cloud.dataflow_v1beta3.types.BigTableIODetails]):
-            Identification of a Cloud BigTable source
+            Identification of a Cloud Bigtable source
             used in the Dataflow job.
         pubsub_details (Sequence[google.cloud.dataflow_v1beta3.types.PubSubIODetails]):
-            Identification of a PubSub source used in the
-            Dataflow job.
+            Identification of a Pub/Sub source used in
+            the Dataflow job.
         file_details (Sequence[google.cloud.dataflow_v1beta3.types.FileIODetails]):
             Identification of a File source used in the
             Dataflow job.
@@ -437,24 +569,40 @@ class JobMetadata(proto.Message):
             the Dataflow job.
     """
 
-    sdk_version = proto.Field(proto.MESSAGE, number=1, message="SdkVersion",)
+    sdk_version = proto.Field(
+        proto.MESSAGE,
+        number=1,
+        message="SdkVersion",
+    )
     spanner_details = proto.RepeatedField(
-        proto.MESSAGE, number=2, message="SpannerIODetails",
+        proto.MESSAGE,
+        number=2,
+        message="SpannerIODetails",
     )
     bigquery_details = proto.RepeatedField(
-        proto.MESSAGE, number=3, message="BigQueryIODetails",
+        proto.MESSAGE,
+        number=3,
+        message="BigQueryIODetails",
     )
     big_table_details = proto.RepeatedField(
-        proto.MESSAGE, number=4, message="BigTableIODetails",
+        proto.MESSAGE,
+        number=4,
+        message="BigTableIODetails",
     )
     pubsub_details = proto.RepeatedField(
-        proto.MESSAGE, number=5, message="PubSubIODetails",
+        proto.MESSAGE,
+        number=5,
+        message="PubSubIODetails",
     )
     file_details = proto.RepeatedField(
-        proto.MESSAGE, number=6, message="FileIODetails",
+        proto.MESSAGE,
+        number=6,
+        message="FileIODetails",
     )
     datastore_details = proto.RepeatedField(
-        proto.MESSAGE, number=7, message="DatastoreIODetails",
+        proto.MESSAGE,
+        number=7,
+        message="DatastoreIODetails",
     )
 
 
@@ -473,10 +621,19 @@ class ExecutionStageState(proto.Message):
             this state.
     """
 
-    execution_stage_name = proto.Field(proto.STRING, number=1,)
-    execution_stage_state = proto.Field(proto.ENUM, number=2, enum="JobState",)
+    execution_stage_name = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    execution_stage_state = proto.Field(
+        proto.ENUM,
+        number=2,
+        enum="JobState",
+    )
     current_state_time = proto.Field(
-        proto.MESSAGE, number=3, message=timestamp_pb2.Timestamp,
+        proto.MESSAGE,
+        number=3,
+        message=timestamp_pb2.Timestamp,
     )
 
 
@@ -498,12 +655,20 @@ class PipelineDescription(proto.Message):
     """
 
     original_pipeline_transform = proto.RepeatedField(
-        proto.MESSAGE, number=1, message="TransformSummary",
+        proto.MESSAGE,
+        number=1,
+        message="TransformSummary",
     )
     execution_pipeline_stage = proto.RepeatedField(
-        proto.MESSAGE, number=2, message="ExecutionStageSummary",
+        proto.MESSAGE,
+        number=2,
+        message="ExecutionStageSummary",
+    )
+    display_data = proto.RepeatedField(
+        proto.MESSAGE,
+        number=3,
+        message="DisplayData",
     )
-    display_data = proto.RepeatedField(proto.MESSAGE, number=3, message="DisplayData",)
 
 
 class TransformSummary(proto.Message):
@@ -528,12 +693,32 @@ class TransformSummary(proto.Message):
             transform.
     """
 
-    kind = proto.Field(proto.ENUM, number=1, enum="KindType",)
-    id = proto.Field(proto.STRING, number=2,)
-    name = proto.Field(proto.STRING, number=3,)
-    display_data = proto.RepeatedField(proto.MESSAGE, number=4, message="DisplayData",)
-    output_collection_name = proto.RepeatedField(proto.STRING, number=5,)
-    input_collection_name = proto.RepeatedField(proto.STRING, number=6,)
+    kind = proto.Field(
+        proto.ENUM,
+        number=1,
+        enum="KindType",
+    )
+    id = proto.Field(
+        proto.STRING,
+        number=2,
+    )
+    name = proto.Field(
+        proto.STRING,
+        number=3,
+    )
+    display_data = proto.RepeatedField(
+        proto.MESSAGE,
+        number=4,
+        message="DisplayData",
+    )
+    output_collection_name = proto.RepeatedField(
+        proto.STRING,
+        number=5,
+    )
+    input_collection_name = proto.RepeatedField(
+        proto.STRING,
+        number=6,
+    )
 
 
 class ExecutionStageSummary(proto.Message):
@@ -583,10 +768,22 @@ class ExecutionStageSummary(proto.Message):
                 Size of the source, if measurable.
         """
 
-        user_name = proto.Field(proto.STRING, number=1,)
-        name = proto.Field(proto.STRING, number=2,)
-        original_transform_or_collection = proto.Field(proto.STRING, number=3,)
-        size_bytes = proto.Field(proto.INT64, number=4,)
+        user_name = proto.Field(
+            proto.STRING,
+            number=1,
+        )
+        name = proto.Field(
+            proto.STRING,
+            number=2,
+        )
+        original_transform_or_collection = proto.Field(
+            proto.STRING,
+            number=3,
+        )
+        size_bytes = proto.Field(
+            proto.INT64,
+            number=4,
+        )
 
     class ComponentTransform(proto.Message):
         r"""Description of a transform executed as part of an execution
@@ -605,9 +802,18 @@ class ExecutionStageSummary(proto.Message):
                 associated.
         """
 
-        user_name = proto.Field(proto.STRING, number=1,)
-        name = proto.Field(proto.STRING, number=2,)
-        original_transform = proto.Field(proto.STRING, number=3,)
+        user_name = proto.Field(
+            proto.STRING,
+            number=1,
+        )
+        name = proto.Field(
+            proto.STRING,
+            number=2,
+        )
+        original_transform = proto.Field(
+            proto.STRING,
+            number=3,
+        )
 
     class ComponentSource(proto.Message):
         r"""Description of an interstitial value between transforms in an
@@ -626,21 +832,55 @@ class ExecutionStageSummary(proto.Message):
                 closely associated.
         """
 
-        user_name = proto.Field(proto.STRING, number=1,)
-        name = proto.Field(proto.STRING, number=2,)
-        original_transform_or_collection = proto.Field(proto.STRING, number=3,)
+        user_name = proto.Field(
+            proto.STRING,
+            number=1,
+        )
+        name = proto.Field(
+            proto.STRING,
+            number=2,
+        )
+        original_transform_or_collection = proto.Field(
+            proto.STRING,
+            number=3,
+        )
 
-    name = proto.Field(proto.STRING, number=1,)
-    id = proto.Field(proto.STRING, number=2,)
-    kind = proto.Field(proto.ENUM, number=3, enum="KindType",)
-    input_source = proto.RepeatedField(proto.MESSAGE, number=4, message=StageSource,)
-    output_source = proto.RepeatedField(proto.MESSAGE, number=5, message=StageSource,)
-    prerequisite_stage = proto.RepeatedField(proto.STRING, number=8,)
+    name = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    id = proto.Field(
+        proto.STRING,
+        number=2,
+    )
+    kind = proto.Field(
+        proto.ENUM,
+        number=3,
+        enum="KindType",
+    )
+    input_source = proto.RepeatedField(
+        proto.MESSAGE,
+        number=4,
+        message=StageSource,
+    )
+    output_source = proto.RepeatedField(
+        proto.MESSAGE,
+        number=5,
+        message=StageSource,
+    )
+    prerequisite_stage = proto.RepeatedField(
+        proto.STRING,
+        number=8,
+    )
     component_transform = proto.RepeatedField(
-        proto.MESSAGE, number=6, message=ComponentTransform,
+        proto.MESSAGE,
+        number=6,
+        message=ComponentTransform,
     )
     component_source = proto.RepeatedField(
-        proto.MESSAGE, number=7, message=ComponentSource,
+        proto.MESSAGE,
+        number=7,
+        message=ComponentSource,
     )
 
 
@@ -648,6 +888,13 @@ class DisplayData(proto.Message):
     r"""Data provided with a pipeline or transform to provide
     descriptive info.
 
+    This message has `oneof`_ fields (mutually exclusive fields).
+    For each oneof, at most one member field can be set at the same time.
+    Setting any member of the oneof automatically clears all other
+    members.
+
+    .. _oneof: https://proto-plus-python.readthedocs.io/en/stable/fields.html#oneofs-mutually-exclusive-fields
+
     Attributes:
         key (str):
             The key identifying the display data.
@@ -663,22 +910,36 @@ class DisplayData(proto.Message):
             rendering.
         str_value (str):
             Contains value if the data is of string type.
+
+            This field is a member of `oneof`_ ``Value``.
         int64_value (int):
             Contains value if the data is of int64 type.
+
+            This field is a member of `oneof`_ ``Value``.
         float_value (float):
             Contains value if the data is of float type.
+
+            This field is a member of `oneof`_ ``Value``.
         java_class_value (str):
             Contains value if the data is of java class
             type.
+
+            This field is a member of `oneof`_ ``Value``.
         timestamp_value (google.protobuf.timestamp_pb2.Timestamp):
             Contains value if the data is of timestamp
             type.
+
+            This field is a member of `oneof`_ ``Value``.
         duration_value (google.protobuf.duration_pb2.Duration):
             Contains value if the data is of duration
             type.
+
+            This field is a member of `oneof`_ ``Value``.
         bool_value (bool):
             Contains value if the data is of a boolean
             type.
+
+            This field is a member of `oneof`_ ``Value``.
         short_str_value (str):
             A possible additional shorter value to display. For example
             a java_class_name_value of com.mypackage.MyDoFn will be
@@ -693,22 +954,63 @@ class DisplayData(proto.Message):
             the element.
     """
 
-    key = proto.Field(proto.STRING, number=1,)
-    namespace = proto.Field(proto.STRING, number=2,)
-    str_value = proto.Field(proto.STRING, number=4, oneof="Value",)
-    int64_value = proto.Field(proto.INT64, number=5, oneof="Value",)
-    float_value = proto.Field(proto.FLOAT, number=6, oneof="Value",)
-    java_class_value = proto.Field(proto.STRING, number=7, oneof="Value",)
+    key = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    namespace = proto.Field(
+        proto.STRING,
+        number=2,
+    )
+    str_value = proto.Field(
+        proto.STRING,
+        number=4,
+        oneof="Value",
+    )
+    int64_value = proto.Field(
+        proto.INT64,
+        number=5,
+        oneof="Value",
+    )
+    float_value = proto.Field(
+        proto.FLOAT,
+        number=6,
+        oneof="Value",
+    )
+    java_class_value = proto.Field(
+        proto.STRING,
+        number=7,
+        oneof="Value",
+    )
     timestamp_value = proto.Field(
-        proto.MESSAGE, number=8, oneof="Value", message=timestamp_pb2.Timestamp,
+        proto.MESSAGE,
+        number=8,
+        oneof="Value",
+        message=timestamp_pb2.Timestamp,
     )
     duration_value = proto.Field(
-        proto.MESSAGE, number=9, oneof="Value", message=duration_pb2.Duration,
+        proto.MESSAGE,
+        number=9,
+        oneof="Value",
+        message=duration_pb2.Duration,
+    )
+    bool_value = proto.Field(
+        proto.BOOL,
+        number=10,
+        oneof="Value",
+    )
+    short_str_value = proto.Field(
+        proto.STRING,
+        number=11,
+    )
+    url = proto.Field(
+        proto.STRING,
+        number=12,
+    )
+    label = proto.Field(
+        proto.STRING,
+        number=13,
     )
-    bool_value = proto.Field(proto.BOOL, number=10, oneof="Value",)
-    short_str_value = proto.Field(proto.STRING, number=11,)
-    url = proto.Field(proto.STRING, number=12,)
-    label = proto.Field(proto.STRING, number=13,)
 
 
 class Step(proto.Message):
@@ -751,9 +1053,19 @@ class Step(proto.Message):
             be provided on Create. Only retrieved with JOB_VIEW_ALL.
     """
 
-    kind = proto.Field(proto.STRING, number=1,)
-    name = proto.Field(proto.STRING, number=2,)
-    properties = proto.Field(proto.MESSAGE, number=3, message=struct_pb2.Struct,)
+    kind = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    name = proto.Field(
+        proto.STRING,
+        number=2,
+    )
+    properties = proto.Field(
+        proto.MESSAGE,
+        number=3,
+        message=struct_pb2.Struct,
+    )
 
 
 class JobExecutionInfo(proto.Message):
@@ -761,13 +1073,16 @@ class JobExecutionInfo(proto.Message):
     executed that isn't contained in the submitted job.
 
     Attributes:
-        stages (Sequence[google.cloud.dataflow_v1beta3.types.JobExecutionInfo.StagesEntry]):
+        stages (Mapping[str, google.cloud.dataflow_v1beta3.types.JobExecutionStageInfo]):
             A mapping from each stage to the information
             about that stage.
     """
 
     stages = proto.MapField(
-        proto.STRING, proto.MESSAGE, number=1, message="JobExecutionStageInfo",
+        proto.STRING,
+        proto.MESSAGE,
+        number=1,
+        message="JobExecutionStageInfo",
     )
 
 
@@ -784,7 +1099,10 @@ class JobExecutionStageInfo(proto.Message):
             one stage.
     """
 
-    step_name = proto.RepeatedField(proto.STRING, number=1,)
+    step_name = proto.RepeatedField(
+        proto.STRING,
+        number=1,
+    )
 
 
 class CreateJobRequest(proto.Message):
@@ -808,11 +1126,28 @@ class CreateJobRequest(proto.Message):
             that contains this job.
     """
 
-    project_id = proto.Field(proto.STRING, number=1,)
-    job = proto.Field(proto.MESSAGE, number=2, message="Job",)
-    view = proto.Field(proto.ENUM, number=3, enum="JobView",)
-    replace_job_id = proto.Field(proto.STRING, number=4,)
-    location = proto.Field(proto.STRING, number=5,)
+    project_id = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    job = proto.Field(
+        proto.MESSAGE,
+        number=2,
+        message="Job",
+    )
+    view = proto.Field(
+        proto.ENUM,
+        number=3,
+        enum="JobView",
+    )
+    replace_job_id = proto.Field(
+        proto.STRING,
+        number=4,
+    )
+    location = proto.Field(
+        proto.STRING,
+        number=5,
+    )
 
 
 class GetJobRequest(proto.Message):
@@ -833,10 +1168,23 @@ class GetJobRequest(proto.Message):
             that contains this job.
     """
 
-    project_id = proto.Field(proto.STRING, number=1,)
-    job_id = proto.Field(proto.STRING, number=2,)
-    view = proto.Field(proto.ENUM, number=3, enum="JobView",)
-    location = proto.Field(proto.STRING, number=4,)
+    project_id = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    job_id = proto.Field(
+        proto.STRING,
+        number=2,
+    )
+    view = proto.Field(
+        proto.ENUM,
+        number=3,
+        enum="JobView",
+    )
+    location = proto.Field(
+        proto.STRING,
+        number=4,
+    )
 
 
 class UpdateJobRequest(proto.Message):
@@ -858,10 +1206,23 @@ class UpdateJobRequest(proto.Message):
             that contains this job.
     """
 
-    project_id = proto.Field(proto.STRING, number=1,)
-    job_id = proto.Field(proto.STRING, number=2,)
-    job = proto.Field(proto.MESSAGE, number=3, message="Job",)
-    location = proto.Field(proto.STRING, number=4,)
+    project_id = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    job_id = proto.Field(
+        proto.STRING,
+        number=2,
+    )
+    job = proto.Field(
+        proto.MESSAGE,
+        number=3,
+        message="Job",
+    )
+    location = proto.Field(
+        proto.STRING,
+        number=4,
+    )
 
 
 class ListJobsRequest(proto.Message):
@@ -898,12 +1259,32 @@ class ListJobsRequest(proto.Message):
         TERMINATED = 2
         ACTIVE = 3
 
-    filter = proto.Field(proto.ENUM, number=5, enum=Filter,)
-    project_id = proto.Field(proto.STRING, number=1,)
-    view = proto.Field(proto.ENUM, number=2, enum="JobView",)
-    page_size = proto.Field(proto.INT32, number=3,)
-    page_token = proto.Field(proto.STRING, number=4,)
-    location = proto.Field(proto.STRING, number=17,)
+    filter = proto.Field(
+        proto.ENUM,
+        number=5,
+        enum=Filter,
+    )
+    project_id = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    view = proto.Field(
+        proto.ENUM,
+        number=2,
+        enum="JobView",
+    )
+    page_size = proto.Field(
+        proto.INT32,
+        number=3,
+    )
+    page_token = proto.Field(
+        proto.STRING,
+        number=4,
+    )
+    location = proto.Field(
+        proto.STRING,
+        number=17,
+    )
 
 
 class FailedLocation(proto.Message):
@@ -918,7 +1299,10 @@ class FailedLocation(proto.Message):
             that failed to respond.
     """
 
-    name = proto.Field(proto.STRING, number=1,)
+    name = proto.Field(
+        proto.STRING,
+        number=1,
+    )
 
 
 class ListJobsResponse(proto.Message):
@@ -944,10 +1328,19 @@ class ListJobsResponse(proto.Message):
     def raw_page(self):
         return self
 
-    jobs = proto.RepeatedField(proto.MESSAGE, number=1, message="Job",)
-    next_page_token = proto.Field(proto.STRING, number=2,)
+    jobs = proto.RepeatedField(
+        proto.MESSAGE,
+        number=1,
+        message="Job",
+    )
+    next_page_token = proto.Field(
+        proto.STRING,
+        number=2,
+    )
     failed_location = proto.RepeatedField(
-        proto.MESSAGE, number=3, message="FailedLocation",
+        proto.MESSAGE,
+        number=3,
+        message="FailedLocation",
     )
 
 
@@ -972,12 +1365,31 @@ class SnapshotJobRequest(proto.Message):
             Maybe empty.
     """
 
-    project_id = proto.Field(proto.STRING, number=1,)
-    job_id = proto.Field(proto.STRING, number=2,)
-    ttl = proto.Field(proto.MESSAGE, number=3, message=duration_pb2.Duration,)
-    location = proto.Field(proto.STRING, number=4,)
-    snapshot_sources = proto.Field(proto.BOOL, number=5,)
-    description = proto.Field(proto.STRING, number=6,)
+    project_id = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    job_id = proto.Field(
+        proto.STRING,
+        number=2,
+    )
+    ttl = proto.Field(
+        proto.MESSAGE,
+        number=3,
+        message=duration_pb2.Duration,
+    )
+    location = proto.Field(
+        proto.STRING,
+        number=4,
+    )
+    snapshot_sources = proto.Field(
+        proto.BOOL,
+        number=5,
+    )
+    description = proto.Field(
+        proto.STRING,
+        number=6,
+    )
 
 
 class CheckActiveJobsRequest(proto.Message):
@@ -988,7 +1400,10 @@ class CheckActiveJobsRequest(proto.Message):
             The project which owns the jobs.
     """
 
-    project_id = proto.Field(proto.STRING, number=1,)
+    project_id = proto.Field(
+        proto.STRING,
+        number=1,
+    )
 
 
 class CheckActiveJobsResponse(proto.Message):
@@ -1000,7 +1415,10 @@ class CheckActiveJobsResponse(proto.Message):
             False otherwise.
     """
 
-    active_jobs_exist = proto.Field(proto.BOOL, number=1,)
+    active_jobs_exist = proto.Field(
+        proto.BOOL,
+        number=1,
+    )
 
 
 __all__ = tuple(sorted(__protobuf__.manifest))
