@@ -13,36 +13,28 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-import os
-import mock
-
-import grpc
-from grpc.experimental import aio
 import math
-import pytest
-from proto.marshal.rules.dates import DurationRule, TimestampRule
-
+import os
 
+from google.api_core import gapic_v1, grpc_helpers, grpc_helpers_async, path_template
 from google.api_core import client_options
 from google.api_core import exceptions as core_exceptions
-from google.api_core import gapic_v1
-from google.api_core import grpc_helpers
-from google.api_core import grpc_helpers_async
-from google.api_core import path_template
+import google.auth
 from google.auth import credentials as ga_credentials
 from google.auth.exceptions import MutualTLSChannelError
+from google.oauth2 import service_account
+import grpc
+from grpc.experimental import aio
+import mock
+from proto.marshal.rules.dates import DurationRule, TimestampRule
+import pytest
+
 from google.cloud.dataflow_v1beta3.services.flex_templates_service import (
     FlexTemplatesServiceAsyncClient,
-)
-from google.cloud.dataflow_v1beta3.services.flex_templates_service import (
     FlexTemplatesServiceClient,
+    transports,
 )
-from google.cloud.dataflow_v1beta3.services.flex_templates_service import transports
-from google.cloud.dataflow_v1beta3.types import environment
-from google.cloud.dataflow_v1beta3.types import jobs
-from google.cloud.dataflow_v1beta3.types import templates
-from google.oauth2 import service_account
-import google.auth
+from google.cloud.dataflow_v1beta3.types import environment, jobs, templates
 
 
 def client_cert_source_callback():
@@ -91,20 +83,26 @@ def test__get_default_mtls_endpoint():
 
 
 @pytest.mark.parametrize(
-    "client_class", [FlexTemplatesServiceClient, FlexTemplatesServiceAsyncClient,]
+    "client_class,transport_name",
+    [
+        (FlexTemplatesServiceClient, "grpc"),
+        (FlexTemplatesServiceAsyncClient, "grpc_asyncio"),
+    ],
 )
-def test_flex_templates_service_client_from_service_account_info(client_class):
+def test_flex_templates_service_client_from_service_account_info(
+    client_class, transport_name
+):
     creds = ga_credentials.AnonymousCredentials()
     with mock.patch.object(
         service_account.Credentials, "from_service_account_info"
     ) as factory:
         factory.return_value = creds
         info = {"valid": True}
-        client = client_class.from_service_account_info(info)
+        client = client_class.from_service_account_info(info, transport=transport_name)
         assert client.transport._credentials == creds
         assert isinstance(client, client_class)
 
-        assert client.transport._host == "dataflow.googleapis.com:443"
+        assert client.transport._host == ("dataflow.googleapis.com:443")
 
 
 @pytest.mark.parametrize(
@@ -133,23 +131,33 @@ def test_flex_templates_service_client_service_account_always_use_jwt(
 
 
 @pytest.mark.parametrize(
-    "client_class", [FlexTemplatesServiceClient, FlexTemplatesServiceAsyncClient,]
+    "client_class,transport_name",
+    [
+        (FlexTemplatesServiceClient, "grpc"),
+        (FlexTemplatesServiceAsyncClient, "grpc_asyncio"),
+    ],
 )
-def test_flex_templates_service_client_from_service_account_file(client_class):
+def test_flex_templates_service_client_from_service_account_file(
+    client_class, transport_name
+):
     creds = ga_credentials.AnonymousCredentials()
     with mock.patch.object(
         service_account.Credentials, "from_service_account_file"
     ) as factory:
         factory.return_value = creds
-        client = client_class.from_service_account_file("dummy/file/path.json")
+        client = client_class.from_service_account_file(
+            "dummy/file/path.json", transport=transport_name
+        )
         assert client.transport._credentials == creds
         assert isinstance(client, client_class)
 
-        client = client_class.from_service_account_json("dummy/file/path.json")
+        client = client_class.from_service_account_json(
+            "dummy/file/path.json", transport=transport_name
+        )
         assert client.transport._credentials == creds
         assert isinstance(client, client_class)
 
-        assert client.transport._host == "dataflow.googleapis.com:443"
+        assert client.transport._host == ("dataflow.googleapis.com:443")
 
 
 def test_flex_templates_service_client_get_transport_class():
@@ -515,7 +523,9 @@ def test_flex_templates_service_client_client_options_scopes(
     client_class, transport_class, transport_name
 ):
     # Check the case scopes are provided.
-    options = client_options.ClientOptions(scopes=["1", "2"],)
+    options = client_options.ClientOptions(
+        scopes=["1", "2"],
+    )
     with mock.patch.object(transport_class, "__init__") as patched:
         patched.return_value = None
         client = client_class(client_options=options, transport=transport_name)
@@ -660,10 +670,17 @@ def test_flex_templates_service_client_create_channel_credentials_file(
         )
 
 
-@pytest.mark.parametrize("request_type", [templates.LaunchFlexTemplateRequest, dict,])
+@pytest.mark.parametrize(
+    "request_type",
+    [
+        templates.LaunchFlexTemplateRequest,
+        dict,
+    ],
+)
 def test_launch_flex_template(request_type, transport: str = "grpc"):
     client = FlexTemplatesServiceClient(
-        credentials=ga_credentials.AnonymousCredentials(), transport=transport,
+        credentials=ga_credentials.AnonymousCredentials(),
+        transport=transport,
     )
 
     # Everything is optional in proto3 as far as the runtime is concerned,
@@ -691,7 +708,8 @@ def test_launch_flex_template_empty_call():
     # This test is a coverage failsafe to make sure that totally empty calls,
     # i.e. request == None and no flattened fields passed, work.
     client = FlexTemplatesServiceClient(
-        credentials=ga_credentials.AnonymousCredentials(), transport="grpc",
+        credentials=ga_credentials.AnonymousCredentials(),
+        transport="grpc",
     )
 
     # Mock the actual call within the gRPC stub, and fake the request.
@@ -709,7 +727,8 @@ async def test_launch_flex_template_async(
     transport: str = "grpc_asyncio", request_type=templates.LaunchFlexTemplateRequest
 ):
     client = FlexTemplatesServiceAsyncClient(
-        credentials=ga_credentials.AnonymousCredentials(), transport=transport,
+        credentials=ga_credentials.AnonymousCredentials(),
+        transport=transport,
     )
 
     # Everything is optional in proto3 as far as the runtime is concerned,
@@ -740,6 +759,73 @@ async def test_launch_flex_template_async_from_dict():
     await test_launch_flex_template_async(request_type=dict)
 
 
+def test_launch_flex_template_field_headers():
+    client = FlexTemplatesServiceClient(
+        credentials=ga_credentials.AnonymousCredentials(),
+    )
+
+    # Any value that is part of the HTTP/1.1 URI should be sent as
+    # a field header. Set these to a non-empty value.
+    request = templates.LaunchFlexTemplateRequest()
+
+    request.project_id = "project_id_value"
+    request.location = "location_value"
+
+    # Mock the actual call within the gRPC stub, and fake the request.
+    with mock.patch.object(
+        type(client.transport.launch_flex_template), "__call__"
+    ) as call:
+        call.return_value = templates.LaunchFlexTemplateResponse()
+        client.launch_flex_template(request)
+
+        # Establish that the underlying gRPC stub method was called.
+        assert len(call.mock_calls) == 1
+        _, args, _ = call.mock_calls[0]
+        assert args[0] == request
+
+    # Establish that the field header was sent.
+    _, _, kw = call.mock_calls[0]
+    assert (
+        "x-goog-request-params",
+        "project_id=project_id_value&location=location_value",
+    ) in kw["metadata"]
+
+
+@pytest.mark.asyncio
+async def test_launch_flex_template_field_headers_async():
+    client = FlexTemplatesServiceAsyncClient(
+        credentials=ga_credentials.AnonymousCredentials(),
+    )
+
+    # Any value that is part of the HTTP/1.1 URI should be sent as
+    # a field header. Set these to a non-empty value.
+    request = templates.LaunchFlexTemplateRequest()
+
+    request.project_id = "project_id_value"
+    request.location = "location_value"
+
+    # Mock the actual call within the gRPC stub, and fake the request.
+    with mock.patch.object(
+        type(client.transport.launch_flex_template), "__call__"
+    ) as call:
+        call.return_value = grpc_helpers_async.FakeUnaryUnaryCall(
+            templates.LaunchFlexTemplateResponse()
+        )
+        await client.launch_flex_template(request)
+
+        # Establish that the underlying gRPC stub method was called.
+        assert len(call.mock_calls)
+        _, args, _ = call.mock_calls[0]
+        assert args[0] == request
+
+    # Establish that the field header was sent.
+    _, _, kw = call.mock_calls[0]
+    assert (
+        "x-goog-request-params",
+        "project_id=project_id_value&location=location_value",
+    ) in kw["metadata"]
+
+
 def test_credentials_transport_error():
     # It is an error to provide credentials and a transport instance.
     transport = transports.FlexTemplatesServiceGrpcTransport(
@@ -747,7 +833,8 @@ def test_credentials_transport_error():
     )
     with pytest.raises(ValueError):
         client = FlexTemplatesServiceClient(
-            credentials=ga_credentials.AnonymousCredentials(), transport=transport,
+            credentials=ga_credentials.AnonymousCredentials(),
+            transport=transport,
         )
 
     # It is an error to provide a credentials file and a transport instance.
@@ -768,7 +855,8 @@ def test_credentials_transport_error():
     options.api_key = "api_key"
     with pytest.raises(ValueError):
         client = FlexTemplatesServiceClient(
-            client_options=options, transport=transport,
+            client_options=options,
+            transport=transport,
         )
 
     # It is an error to provide an api_key and a credential.
@@ -785,7 +873,8 @@ def test_credentials_transport_error():
     )
     with pytest.raises(ValueError):
         client = FlexTemplatesServiceClient(
-            client_options={"scopes": ["1", "2"]}, transport=transport,
+            client_options={"scopes": ["1", "2"]},
+            transport=transport,
         )
 
 
@@ -828,12 +917,28 @@ def test_transport_adc(transport_class):
         adc.assert_called_once()
 
 
+@pytest.mark.parametrize(
+    "transport_name",
+    [
+        "grpc",
+    ],
+)
+def test_transport_kind(transport_name):
+    transport = FlexTemplatesServiceClient.get_transport_class(transport_name)(
+        credentials=ga_credentials.AnonymousCredentials(),
+    )
+    assert transport.kind == transport_name
+
+
 def test_transport_grpc_default():
     # A client should use the gRPC transport by default.
     client = FlexTemplatesServiceClient(
         credentials=ga_credentials.AnonymousCredentials(),
     )
-    assert isinstance(client.transport, transports.FlexTemplatesServiceGrpcTransport,)
+    assert isinstance(
+        client.transport,
+        transports.FlexTemplatesServiceGrpcTransport,
+    )
 
 
 def test_flex_templates_service_base_transport_error():
@@ -865,6 +970,14 @@ def test_flex_templates_service_base_transport():
     with pytest.raises(NotImplementedError):
         transport.close()
 
+    # Catch all for all remaining methods and properties
+    remainder = [
+        "kind",
+    ]
+    for r in remainder:
+        with pytest.raises(NotImplementedError):
+            getattr(transport, r)()
+
 
 def test_flex_templates_service_base_transport_with_credentials_file():
     # Instantiate the base transport with a credentials file
@@ -876,7 +989,8 @@ def test_flex_templates_service_base_transport_with_credentials_file():
         Transport.return_value = None
         load_creds.return_value = (ga_credentials.AnonymousCredentials(), None)
         transport = transports.FlexTemplatesServiceTransport(
-            credentials_file="credentials.json", quota_project_id="octopus",
+            credentials_file="credentials.json",
+            quota_project_id="octopus",
         )
         load_creds.assert_called_once_with(
             "credentials.json",
@@ -1031,24 +1145,40 @@ def test_flex_templates_service_grpc_transport_client_cert_source_for_mtls(
             )
 
 
-def test_flex_templates_service_host_no_port():
+@pytest.mark.parametrize(
+    "transport_name",
+    [
+        "grpc",
+        "grpc_asyncio",
+    ],
+)
+def test_flex_templates_service_host_no_port(transport_name):
     client = FlexTemplatesServiceClient(
         credentials=ga_credentials.AnonymousCredentials(),
         client_options=client_options.ClientOptions(
             api_endpoint="dataflow.googleapis.com"
         ),
+        transport=transport_name,
     )
-    assert client.transport._host == "dataflow.googleapis.com:443"
+    assert client.transport._host == ("dataflow.googleapis.com:443")
 
 
-def test_flex_templates_service_host_with_port():
+@pytest.mark.parametrize(
+    "transport_name",
+    [
+        "grpc",
+        "grpc_asyncio",
+    ],
+)
+def test_flex_templates_service_host_with_port(transport_name):
     client = FlexTemplatesServiceClient(
         credentials=ga_credentials.AnonymousCredentials(),
         client_options=client_options.ClientOptions(
             api_endpoint="dataflow.googleapis.com:8000"
         ),
+        transport=transport_name,
     )
-    assert client.transport._host == "dataflow.googleapis.com:8000"
+    assert client.transport._host == ("dataflow.googleapis.com:8000")
 
 
 def test_flex_templates_service_grpc_transport_channel():
@@ -1056,7 +1186,8 @@ def test_flex_templates_service_grpc_transport_channel():
 
     # Check that channel is used if provided.
     transport = transports.FlexTemplatesServiceGrpcTransport(
-        host="squid.clam.whelk", channel=channel,
+        host="squid.clam.whelk",
+        channel=channel,
     )
     assert transport.grpc_channel == channel
     assert transport._host == "squid.clam.whelk:443"
@@ -1068,7 +1199,8 @@ def test_flex_templates_service_grpc_asyncio_transport_channel():
 
     # Check that channel is used if provided.
     transport = transports.FlexTemplatesServiceGrpcAsyncIOTransport(
-        host="squid.clam.whelk", channel=channel,
+        host="squid.clam.whelk",
+        channel=channel,
     )
     assert transport.grpc_channel == channel
     assert transport._host == "squid.clam.whelk:443"
@@ -1197,7 +1329,9 @@ def test_parse_common_billing_account_path():
 
 def test_common_folder_path():
     folder = "whelk"
-    expected = "folders/{folder}".format(folder=folder,)
+    expected = "folders/{folder}".format(
+        folder=folder,
+    )
     actual = FlexTemplatesServiceClient.common_folder_path(folder)
     assert expected == actual
 
@@ -1215,7 +1349,9 @@ def test_parse_common_folder_path():
 
 def test_common_organization_path():
     organization = "oyster"
-    expected = "organizations/{organization}".format(organization=organization,)
+    expected = "organizations/{organization}".format(
+        organization=organization,
+    )
     actual = FlexTemplatesServiceClient.common_organization_path(organization)
     assert expected == actual
 
@@ -1233,7 +1369,9 @@ def test_parse_common_organization_path():
 
 def test_common_project_path():
     project = "cuttlefish"
-    expected = "projects/{project}".format(project=project,)
+    expected = "projects/{project}".format(
+        project=project,
+    )
     actual = FlexTemplatesServiceClient.common_project_path(project)
     assert expected == actual
 
@@ -1253,7 +1391,8 @@ def test_common_location_path():
     project = "winkle"
     location = "nautilus"
     expected = "projects/{project}/locations/{location}".format(
-        project=project, location=location,
+        project=project,
+        location=location,
     )
     actual = FlexTemplatesServiceClient.common_location_path(project, location)
     assert expected == actual
@@ -1278,7 +1417,8 @@ def test_client_with_default_client_info():
         transports.FlexTemplatesServiceTransport, "_prep_wrapped_messages"
     ) as prep:
         client = FlexTemplatesServiceClient(
-            credentials=ga_credentials.AnonymousCredentials(), client_info=client_info,
+            credentials=ga_credentials.AnonymousCredentials(),
+            client_info=client_info,
         )
         prep.assert_called_once_with(client_info)
 
@@ -1287,7 +1427,8 @@ def test_client_with_default_client_info():
     ) as prep:
         transport_class = FlexTemplatesServiceClient.get_transport_class()
         transport = transport_class(
-            credentials=ga_credentials.AnonymousCredentials(), client_info=client_info,
+            credentials=ga_credentials.AnonymousCredentials(),
+            client_info=client_info,
         )
         prep.assert_called_once_with(client_info)
 
@@ -1295,7 +1436,8 @@ def test_client_with_default_client_info():
 @pytest.mark.asyncio
 async def test_transport_close_async():
     client = FlexTemplatesServiceAsyncClient(
-        credentials=ga_credentials.AnonymousCredentials(), transport="grpc_asyncio",
+        credentials=ga_credentials.AnonymousCredentials(),
+        transport="grpc_asyncio",
     )
     with mock.patch.object(
         type(getattr(client.transport, "grpc_channel")), "close"
