@@ -13,36 +13,30 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-import os
-import mock
-
-import grpc
-from grpc.experimental import aio
 import math
-import pytest
-from proto.marshal.rules.dates import DurationRule, TimestampRule
-
+import os
 
+from google.api_core import gapic_v1, grpc_helpers, grpc_helpers_async, path_template
 from google.api_core import client_options
 from google.api_core import exceptions as core_exceptions
-from google.api_core import gapic_v1
-from google.api_core import grpc_helpers
-from google.api_core import grpc_helpers_async
-from google.api_core import path_template
+import google.auth
 from google.auth import credentials as ga_credentials
 from google.auth.exceptions import MutualTLSChannelError
-from google.cloud.dataflow_v1beta3.services.messages_v1_beta3 import (
-    MessagesV1Beta3AsyncClient,
-)
-from google.cloud.dataflow_v1beta3.services.messages_v1_beta3 import (
-    MessagesV1Beta3Client,
-)
-from google.cloud.dataflow_v1beta3.services.messages_v1_beta3 import pagers
-from google.cloud.dataflow_v1beta3.services.messages_v1_beta3 import transports
-from google.cloud.dataflow_v1beta3.types import messages
 from google.oauth2 import service_account
 from google.protobuf import timestamp_pb2  # type: ignore
-import google.auth
+import grpc
+from grpc.experimental import aio
+import mock
+from proto.marshal.rules.dates import DurationRule, TimestampRule
+import pytest
+
+from google.cloud.dataflow_v1beta3.services.messages_v1_beta3 import (
+    MessagesV1Beta3AsyncClient,
+    MessagesV1Beta3Client,
+    pagers,
+    transports,
+)
+from google.cloud.dataflow_v1beta3.types import messages
 
 
 def client_cert_source_callback():
@@ -90,20 +84,26 @@ def test__get_default_mtls_endpoint():
 
 
 @pytest.mark.parametrize(
-    "client_class", [MessagesV1Beta3Client, MessagesV1Beta3AsyncClient,]
+    "client_class,transport_name",
+    [
+        (MessagesV1Beta3Client, "grpc"),
+        (MessagesV1Beta3AsyncClient, "grpc_asyncio"),
+    ],
 )
-def test_messages_v1_beta3_client_from_service_account_info(client_class):
+def test_messages_v1_beta3_client_from_service_account_info(
+    client_class, transport_name
+):
     creds = ga_credentials.AnonymousCredentials()
     with mock.patch.object(
         service_account.Credentials, "from_service_account_info"
     ) as factory:
         factory.return_value = creds
         info = {"valid": True}
-        client = client_class.from_service_account_info(info)
+        client = client_class.from_service_account_info(info, transport=transport_name)
         assert client.transport._credentials == creds
         assert isinstance(client, client_class)
 
-        assert client.transport._host == "dataflow.googleapis.com:443"
+        assert client.transport._host == ("dataflow.googleapis.com:443")
 
 
 @pytest.mark.parametrize(
@@ -132,23 +132,33 @@ def test_messages_v1_beta3_client_service_account_always_use_jwt(
 
 
 @pytest.mark.parametrize(
-    "client_class", [MessagesV1Beta3Client, MessagesV1Beta3AsyncClient,]
+    "client_class,transport_name",
+    [
+        (MessagesV1Beta3Client, "grpc"),
+        (MessagesV1Beta3AsyncClient, "grpc_asyncio"),
+    ],
 )
-def test_messages_v1_beta3_client_from_service_account_file(client_class):
+def test_messages_v1_beta3_client_from_service_account_file(
+    client_class, transport_name
+):
     creds = ga_credentials.AnonymousCredentials()
     with mock.patch.object(
         service_account.Credentials, "from_service_account_file"
     ) as factory:
         factory.return_value = creds
-        client = client_class.from_service_account_file("dummy/file/path.json")
+        client = client_class.from_service_account_file(
+            "dummy/file/path.json", transport=transport_name
+        )
         assert client.transport._credentials == creds
         assert isinstance(client, client_class)
 
-        client = client_class.from_service_account_json("dummy/file/path.json")
+        client = client_class.from_service_account_json(
+            "dummy/file/path.json", transport=transport_name
+        )
         assert client.transport._credentials == creds
         assert isinstance(client, client_class)
 
-        assert client.transport._host == "dataflow.googleapis.com:443"
+        assert client.transport._host == ("dataflow.googleapis.com:443")
 
 
 def test_messages_v1_beta3_client_get_transport_class():
@@ -506,7 +516,9 @@ def test_messages_v1_beta3_client_client_options_scopes(
     client_class, transport_class, transport_name
 ):
     # Check the case scopes are provided.
-    options = client_options.ClientOptions(scopes=["1", "2"],)
+    options = client_options.ClientOptions(
+        scopes=["1", "2"],
+    )
     with mock.patch.object(transport_class, "__init__") as patched:
         patched.return_value = None
         client = client_class(client_options=options, transport=transport_name)
@@ -651,10 +663,17 @@ def test_messages_v1_beta3_client_create_channel_credentials_file(
         )
 
 
-@pytest.mark.parametrize("request_type", [messages.ListJobMessagesRequest, dict,])
+@pytest.mark.parametrize(
+    "request_type",
+    [
+        messages.ListJobMessagesRequest,
+        dict,
+    ],
+)
 def test_list_job_messages(request_type, transport: str = "grpc"):
     client = MessagesV1Beta3Client(
-        credentials=ga_credentials.AnonymousCredentials(), transport=transport,
+        credentials=ga_credentials.AnonymousCredentials(),
+        transport=transport,
     )
 
     # Everything is optional in proto3 as far as the runtime is concerned,
@@ -685,7 +704,8 @@ def test_list_job_messages_empty_call():
     # This test is a coverage failsafe to make sure that totally empty calls,
     # i.e. request == None and no flattened fields passed, work.
     client = MessagesV1Beta3Client(
-        credentials=ga_credentials.AnonymousCredentials(), transport="grpc",
+        credentials=ga_credentials.AnonymousCredentials(),
+        transport="grpc",
     )
 
     # Mock the actual call within the gRPC stub, and fake the request.
@@ -703,7 +723,8 @@ async def test_list_job_messages_async(
     transport: str = "grpc_asyncio", request_type=messages.ListJobMessagesRequest
 ):
     client = MessagesV1Beta3AsyncClient(
-        credentials=ga_credentials.AnonymousCredentials(), transport=transport,
+        credentials=ga_credentials.AnonymousCredentials(),
+        transport=transport,
     )
 
     # Everything is optional in proto3 as far as the runtime is concerned,
@@ -716,7 +737,9 @@ async def test_list_job_messages_async(
     ) as call:
         # Designate an appropriate return value for the call.
         call.return_value = grpc_helpers_async.FakeUnaryUnaryCall(
-            messages.ListJobMessagesResponse(next_page_token="next_page_token_value",)
+            messages.ListJobMessagesResponse(
+                next_page_token="next_page_token_value",
+            )
         )
         response = await client.list_job_messages(request)
 
@@ -735,9 +758,79 @@ async def test_list_job_messages_async_from_dict():
     await test_list_job_messages_async(request_type=dict)
 
 
+def test_list_job_messages_field_headers():
+    client = MessagesV1Beta3Client(
+        credentials=ga_credentials.AnonymousCredentials(),
+    )
+
+    # Any value that is part of the HTTP/1.1 URI should be sent as
+    # a field header. Set these to a non-empty value.
+    request = messages.ListJobMessagesRequest()
+
+    request.project_id = "project_id_value"
+    request.location = "location_value"
+    request.job_id = "job_id_value"
+
+    # Mock the actual call within the gRPC stub, and fake the request.
+    with mock.patch.object(
+        type(client.transport.list_job_messages), "__call__"
+    ) as call:
+        call.return_value = messages.ListJobMessagesResponse()
+        client.list_job_messages(request)
+
+        # Establish that the underlying gRPC stub method was called.
+        assert len(call.mock_calls) == 1
+        _, args, _ = call.mock_calls[0]
+        assert args[0] == request
+
+    # Establish that the field header was sent.
+    _, _, kw = call.mock_calls[0]
+    assert (
+        "x-goog-request-params",
+        "project_id=project_id_value&location=location_value&job_id=job_id_value",
+    ) in kw["metadata"]
+
+
+@pytest.mark.asyncio
+async def test_list_job_messages_field_headers_async():
+    client = MessagesV1Beta3AsyncClient(
+        credentials=ga_credentials.AnonymousCredentials(),
+    )
+
+    # Any value that is part of the HTTP/1.1 URI should be sent as
+    # a field header. Set these to a non-empty value.
+    request = messages.ListJobMessagesRequest()
+
+    request.project_id = "project_id_value"
+    request.location = "location_value"
+    request.job_id = "job_id_value"
+
+    # Mock the actual call within the gRPC stub, and fake the request.
+    with mock.patch.object(
+        type(client.transport.list_job_messages), "__call__"
+    ) as call:
+        call.return_value = grpc_helpers_async.FakeUnaryUnaryCall(
+            messages.ListJobMessagesResponse()
+        )
+        await client.list_job_messages(request)
+
+        # Establish that the underlying gRPC stub method was called.
+        assert len(call.mock_calls)
+        _, args, _ = call.mock_calls[0]
+        assert args[0] == request
+
+    # Establish that the field header was sent.
+    _, _, kw = call.mock_calls[0]
+    assert (
+        "x-goog-request-params",
+        "project_id=project_id_value&location=location_value&job_id=job_id_value",
+    ) in kw["metadata"]
+
+
 def test_list_job_messages_pager(transport_name: str = "grpc"):
     client = MessagesV1Beta3Client(
-        credentials=ga_credentials.AnonymousCredentials, transport=transport_name,
+        credentials=ga_credentials.AnonymousCredentials,
+        transport=transport_name,
     )
 
     # Mock the actual call within the gRPC stub, and fake the request.
@@ -754,29 +847,48 @@ def test_list_job_messages_pager(transport_name: str = "grpc"):
                 ],
                 next_page_token="abc",
             ),
-            messages.ListJobMessagesResponse(job_messages=[], next_page_token="def",),
             messages.ListJobMessagesResponse(
-                job_messages=[messages.JobMessage(),], next_page_token="ghi",
+                job_messages=[],
+                next_page_token="def",
             ),
             messages.ListJobMessagesResponse(
-                job_messages=[messages.JobMessage(), messages.JobMessage(),],
+                job_messages=[
+                    messages.JobMessage(),
+                ],
+                next_page_token="ghi",
+            ),
+            messages.ListJobMessagesResponse(
+                job_messages=[
+                    messages.JobMessage(),
+                    messages.JobMessage(),
+                ],
             ),
             RuntimeError,
         )
 
         metadata = ()
+        metadata = tuple(metadata) + (
+            gapic_v1.routing_header.to_grpc_metadata(
+                (
+                    ("project_id", ""),
+                    ("location", ""),
+                    ("job_id", ""),
+                )
+            ),
+        )
         pager = client.list_job_messages(request={})
 
         assert pager._metadata == metadata
 
-        results = [i for i in pager]
+        results = list(pager)
         assert len(results) == 6
         assert all(isinstance(i, messages.JobMessage) for i in results)
 
 
 def test_list_job_messages_pages(transport_name: str = "grpc"):
     client = MessagesV1Beta3Client(
-        credentials=ga_credentials.AnonymousCredentials, transport=transport_name,
+        credentials=ga_credentials.AnonymousCredentials,
+        transport=transport_name,
     )
 
     # Mock the actual call within the gRPC stub, and fake the request.
@@ -793,12 +905,21 @@ def test_list_job_messages_pages(transport_name: str = "grpc"):
                 ],
                 next_page_token="abc",
             ),
-            messages.ListJobMessagesResponse(job_messages=[], next_page_token="def",),
             messages.ListJobMessagesResponse(
-                job_messages=[messages.JobMessage(),], next_page_token="ghi",
+                job_messages=[],
+                next_page_token="def",
             ),
             messages.ListJobMessagesResponse(
-                job_messages=[messages.JobMessage(), messages.JobMessage(),],
+                job_messages=[
+                    messages.JobMessage(),
+                ],
+                next_page_token="ghi",
+            ),
+            messages.ListJobMessagesResponse(
+                job_messages=[
+                    messages.JobMessage(),
+                    messages.JobMessage(),
+                ],
             ),
             RuntimeError,
         )
@@ -829,19 +950,30 @@ async def test_list_job_messages_async_pager():
                 ],
                 next_page_token="abc",
             ),
-            messages.ListJobMessagesResponse(job_messages=[], next_page_token="def",),
             messages.ListJobMessagesResponse(
-                job_messages=[messages.JobMessage(),], next_page_token="ghi",
+                job_messages=[],
+                next_page_token="def",
             ),
             messages.ListJobMessagesResponse(
-                job_messages=[messages.JobMessage(), messages.JobMessage(),],
+                job_messages=[
+                    messages.JobMessage(),
+                ],
+                next_page_token="ghi",
+            ),
+            messages.ListJobMessagesResponse(
+                job_messages=[
+                    messages.JobMessage(),
+                    messages.JobMessage(),
+                ],
             ),
             RuntimeError,
         )
-        async_pager = await client.list_job_messages(request={},)
+        async_pager = await client.list_job_messages(
+            request={},
+        )
         assert async_pager.next_page_token == "abc"
         responses = []
-        async for response in async_pager:
+        async for response in async_pager:  # pragma: no branch
             responses.append(response)
 
         assert len(responses) == 6
@@ -870,17 +1002,28 @@ async def test_list_job_messages_async_pages():
                 ],
                 next_page_token="abc",
             ),
-            messages.ListJobMessagesResponse(job_messages=[], next_page_token="def",),
             messages.ListJobMessagesResponse(
-                job_messages=[messages.JobMessage(),], next_page_token="ghi",
+                job_messages=[],
+                next_page_token="def",
             ),
             messages.ListJobMessagesResponse(
-                job_messages=[messages.JobMessage(), messages.JobMessage(),],
+                job_messages=[
+                    messages.JobMessage(),
+                ],
+                next_page_token="ghi",
+            ),
+            messages.ListJobMessagesResponse(
+                job_messages=[
+                    messages.JobMessage(),
+                    messages.JobMessage(),
+                ],
             ),
             RuntimeError,
         )
         pages = []
-        async for page_ in (await client.list_job_messages(request={})).pages:
+        async for page_ in (
+            await client.list_job_messages(request={})
+        ).pages:  # pragma: no branch
             pages.append(page_)
         for page_, token in zip(pages, ["abc", "def", "ghi", ""]):
             assert page_.raw_page.next_page_token == token
@@ -893,7 +1036,8 @@ def test_credentials_transport_error():
     )
     with pytest.raises(ValueError):
         client = MessagesV1Beta3Client(
-            credentials=ga_credentials.AnonymousCredentials(), transport=transport,
+            credentials=ga_credentials.AnonymousCredentials(),
+            transport=transport,
         )
 
     # It is an error to provide a credentials file and a transport instance.
@@ -913,7 +1057,10 @@ def test_credentials_transport_error():
     options = client_options.ClientOptions()
     options.api_key = "api_key"
     with pytest.raises(ValueError):
-        client = MessagesV1Beta3Client(client_options=options, transport=transport,)
+        client = MessagesV1Beta3Client(
+            client_options=options,
+            transport=transport,
+        )
 
     # It is an error to provide an api_key and a credential.
     options = mock.Mock()
@@ -929,7 +1076,8 @@ def test_credentials_transport_error():
     )
     with pytest.raises(ValueError):
         client = MessagesV1Beta3Client(
-            client_options={"scopes": ["1", "2"]}, transport=transport,
+            client_options={"scopes": ["1", "2"]},
+            transport=transport,
         )
 
 
@@ -972,10 +1120,28 @@ def test_transport_adc(transport_class):
         adc.assert_called_once()
 
 
+@pytest.mark.parametrize(
+    "transport_name",
+    [
+        "grpc",
+    ],
+)
+def test_transport_kind(transport_name):
+    transport = MessagesV1Beta3Client.get_transport_class(transport_name)(
+        credentials=ga_credentials.AnonymousCredentials(),
+    )
+    assert transport.kind == transport_name
+
+
 def test_transport_grpc_default():
     # A client should use the gRPC transport by default.
-    client = MessagesV1Beta3Client(credentials=ga_credentials.AnonymousCredentials(),)
-    assert isinstance(client.transport, transports.MessagesV1Beta3GrpcTransport,)
+    client = MessagesV1Beta3Client(
+        credentials=ga_credentials.AnonymousCredentials(),
+    )
+    assert isinstance(
+        client.transport,
+        transports.MessagesV1Beta3GrpcTransport,
+    )
 
 
 def test_messages_v1_beta3_base_transport_error():
@@ -1007,6 +1173,14 @@ def test_messages_v1_beta3_base_transport():
     with pytest.raises(NotImplementedError):
         transport.close()
 
+    # Catch all for all remaining methods and properties
+    remainder = [
+        "kind",
+    ]
+    for r in remainder:
+        with pytest.raises(NotImplementedError):
+            getattr(transport, r)()
+
 
 def test_messages_v1_beta3_base_transport_with_credentials_file():
     # Instantiate the base transport with a credentials file
@@ -1018,7 +1192,8 @@ def test_messages_v1_beta3_base_transport_with_credentials_file():
         Transport.return_value = None
         load_creds.return_value = (ga_credentials.AnonymousCredentials(), None)
         transport = transports.MessagesV1Beta3Transport(
-            credentials_file="credentials.json", quota_project_id="octopus",
+            credentials_file="credentials.json",
+            quota_project_id="octopus",
         )
         load_creds.assert_called_once_with(
             "credentials.json",
@@ -1171,24 +1346,40 @@ def test_messages_v1_beta3_grpc_transport_client_cert_source_for_mtls(transport_
             )
 
 
-def test_messages_v1_beta3_host_no_port():
+@pytest.mark.parametrize(
+    "transport_name",
+    [
+        "grpc",
+        "grpc_asyncio",
+    ],
+)
+def test_messages_v1_beta3_host_no_port(transport_name):
     client = MessagesV1Beta3Client(
         credentials=ga_credentials.AnonymousCredentials(),
         client_options=client_options.ClientOptions(
             api_endpoint="dataflow.googleapis.com"
         ),
+        transport=transport_name,
     )
-    assert client.transport._host == "dataflow.googleapis.com:443"
+    assert client.transport._host == ("dataflow.googleapis.com:443")
 
 
-def test_messages_v1_beta3_host_with_port():
+@pytest.mark.parametrize(
+    "transport_name",
+    [
+        "grpc",
+        "grpc_asyncio",
+    ],
+)
+def test_messages_v1_beta3_host_with_port(transport_name):
     client = MessagesV1Beta3Client(
         credentials=ga_credentials.AnonymousCredentials(),
         client_options=client_options.ClientOptions(
             api_endpoint="dataflow.googleapis.com:8000"
         ),
+        transport=transport_name,
     )
-    assert client.transport._host == "dataflow.googleapis.com:8000"
+    assert client.transport._host == ("dataflow.googleapis.com:8000")
 
 
 def test_messages_v1_beta3_grpc_transport_channel():
@@ -1196,7 +1387,8 @@ def test_messages_v1_beta3_grpc_transport_channel():
 
     # Check that channel is used if provided.
     transport = transports.MessagesV1Beta3GrpcTransport(
-        host="squid.clam.whelk", channel=channel,
+        host="squid.clam.whelk",
+        channel=channel,
     )
     assert transport.grpc_channel == channel
     assert transport._host == "squid.clam.whelk:443"
@@ -1208,7 +1400,8 @@ def test_messages_v1_beta3_grpc_asyncio_transport_channel():
 
     # Check that channel is used if provided.
     transport = transports.MessagesV1Beta3GrpcAsyncIOTransport(
-        host="squid.clam.whelk", channel=channel,
+        host="squid.clam.whelk",
+        channel=channel,
     )
     assert transport.grpc_channel == channel
     assert transport._host == "squid.clam.whelk:443"
@@ -1337,7 +1530,9 @@ def test_parse_common_billing_account_path():
 
 def test_common_folder_path():
     folder = "whelk"
-    expected = "folders/{folder}".format(folder=folder,)
+    expected = "folders/{folder}".format(
+        folder=folder,
+    )
     actual = MessagesV1Beta3Client.common_folder_path(folder)
     assert expected == actual
 
@@ -1355,7 +1550,9 @@ def test_parse_common_folder_path():
 
 def test_common_organization_path():
     organization = "oyster"
-    expected = "organizations/{organization}".format(organization=organization,)
+    expected = "organizations/{organization}".format(
+        organization=organization,
+    )
     actual = MessagesV1Beta3Client.common_organization_path(organization)
     assert expected == actual
 
@@ -1373,7 +1570,9 @@ def test_parse_common_organization_path():
 
 def test_common_project_path():
     project = "cuttlefish"
-    expected = "projects/{project}".format(project=project,)
+    expected = "projects/{project}".format(
+        project=project,
+    )
     actual = MessagesV1Beta3Client.common_project_path(project)
     assert expected == actual
 
@@ -1393,7 +1592,8 @@ def test_common_location_path():
     project = "winkle"
     location = "nautilus"
     expected = "projects/{project}/locations/{location}".format(
-        project=project, location=location,
+        project=project,
+        location=location,
     )
     actual = MessagesV1Beta3Client.common_location_path(project, location)
     assert expected == actual
@@ -1418,7 +1618,8 @@ def test_client_with_default_client_info():
         transports.MessagesV1Beta3Transport, "_prep_wrapped_messages"
     ) as prep:
         client = MessagesV1Beta3Client(
-            credentials=ga_credentials.AnonymousCredentials(), client_info=client_info,
+            credentials=ga_credentials.AnonymousCredentials(),
+            client_info=client_info,
         )
         prep.assert_called_once_with(client_info)
 
@@ -1427,7 +1628,8 @@ def test_client_with_default_client_info():
     ) as prep:
         transport_class = MessagesV1Beta3Client.get_transport_class()
         transport = transport_class(
-            credentials=ga_credentials.AnonymousCredentials(), client_info=client_info,
+            credentials=ga_credentials.AnonymousCredentials(),
+            client_info=client_info,
         )
         prep.assert_called_once_with(client_info)
 
@@ -1435,7 +1637,8 @@ def test_client_with_default_client_info():
 @pytest.mark.asyncio
 async def test_transport_close_async():
     client = MessagesV1Beta3AsyncClient(
-        credentials=ga_credentials.AnonymousCredentials(), transport="grpc_asyncio",
+        credentials=ga_credentials.AnonymousCredentials(),
+        transport="grpc_asyncio",
     )
     with mock.patch.object(
         type(getattr(client.transport, "grpc_channel")), "close"
