@@ -13,36 +13,30 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-import os
-import mock
-
-import grpc
-from grpc.experimental import aio
 import math
-import pytest
-from proto.marshal.rules.dates import DurationRule, TimestampRule
-
+import os
 
+from google.api_core import gapic_v1, grpc_helpers, grpc_helpers_async, path_template
 from google.api_core import client_options
 from google.api_core import exceptions as core_exceptions
-from google.api_core import gapic_v1
-from google.api_core import grpc_helpers
-from google.api_core import grpc_helpers_async
-from google.api_core import path_template
+import google.auth
 from google.auth import credentials as ga_credentials
 from google.auth.exceptions import MutualTLSChannelError
-from google.cloud.dataflow_v1beta3.services.snapshots_v1_beta3 import (
-    SnapshotsV1Beta3AsyncClient,
-)
-from google.cloud.dataflow_v1beta3.services.snapshots_v1_beta3 import (
-    SnapshotsV1Beta3Client,
-)
-from google.cloud.dataflow_v1beta3.services.snapshots_v1_beta3 import transports
-from google.cloud.dataflow_v1beta3.types import snapshots
 from google.oauth2 import service_account
 from google.protobuf import duration_pb2  # type: ignore
 from google.protobuf import timestamp_pb2  # type: ignore
-import google.auth
+import grpc
+from grpc.experimental import aio
+import mock
+from proto.marshal.rules.dates import DurationRule, TimestampRule
+import pytest
+
+from google.cloud.dataflow_v1beta3.services.snapshots_v1_beta3 import (
+    SnapshotsV1Beta3AsyncClient,
+    SnapshotsV1Beta3Client,
+    transports,
+)
+from google.cloud.dataflow_v1beta3.types import snapshots
 
 
 def client_cert_source_callback():
@@ -91,20 +85,26 @@ def test__get_default_mtls_endpoint():
 
 
 @pytest.mark.parametrize(
-    "client_class", [SnapshotsV1Beta3Client, SnapshotsV1Beta3AsyncClient,]
+    "client_class,transport_name",
+    [
+        (SnapshotsV1Beta3Client, "grpc"),
+        (SnapshotsV1Beta3AsyncClient, "grpc_asyncio"),
+    ],
 )
-def test_snapshots_v1_beta3_client_from_service_account_info(client_class):
+def test_snapshots_v1_beta3_client_from_service_account_info(
+    client_class, transport_name
+):
     creds = ga_credentials.AnonymousCredentials()
     with mock.patch.object(
         service_account.Credentials, "from_service_account_info"
     ) as factory:
         factory.return_value = creds
         info = {"valid": True}
-        client = client_class.from_service_account_info(info)
+        client = client_class.from_service_account_info(info, transport=transport_name)
         assert client.transport._credentials == creds
         assert isinstance(client, client_class)
 
-        assert client.transport._host == "dataflow.googleapis.com:443"
+        assert client.transport._host == ("dataflow.googleapis.com:443")
 
 
 @pytest.mark.parametrize(
@@ -133,23 +133,33 @@ def test_snapshots_v1_beta3_client_service_account_always_use_jwt(
 
 
 @pytest.mark.parametrize(
-    "client_class", [SnapshotsV1Beta3Client, SnapshotsV1Beta3AsyncClient,]
+    "client_class,transport_name",
+    [
+        (SnapshotsV1Beta3Client, "grpc"),
+        (SnapshotsV1Beta3AsyncClient, "grpc_asyncio"),
+    ],
 )
-def test_snapshots_v1_beta3_client_from_service_account_file(client_class):
+def test_snapshots_v1_beta3_client_from_service_account_file(
+    client_class, transport_name
+):
     creds = ga_credentials.AnonymousCredentials()
     with mock.patch.object(
         service_account.Credentials, "from_service_account_file"
     ) as factory:
         factory.return_value = creds
-        client = client_class.from_service_account_file("dummy/file/path.json")
+        client = client_class.from_service_account_file(
+            "dummy/file/path.json", transport=transport_name
+        )
         assert client.transport._credentials == creds
         assert isinstance(client, client_class)
 
-        client = client_class.from_service_account_json("dummy/file/path.json")
+        client = client_class.from_service_account_json(
+            "dummy/file/path.json", transport=transport_name
+        )
         assert client.transport._credentials == creds
         assert isinstance(client, client_class)
 
-        assert client.transport._host == "dataflow.googleapis.com:443"
+        assert client.transport._host == ("dataflow.googleapis.com:443")
 
 
 def test_snapshots_v1_beta3_client_get_transport_class():
@@ -507,7 +517,9 @@ def test_snapshots_v1_beta3_client_client_options_scopes(
     client_class, transport_class, transport_name
 ):
     # Check the case scopes are provided.
-    options = client_options.ClientOptions(scopes=["1", "2"],)
+    options = client_options.ClientOptions(
+        scopes=["1", "2"],
+    )
     with mock.patch.object(transport_class, "__init__") as patched:
         patched.return_value = None
         client = client_class(client_options=options, transport=transport_name)
@@ -652,10 +664,17 @@ def test_snapshots_v1_beta3_client_create_channel_credentials_file(
         )
 
 
-@pytest.mark.parametrize("request_type", [snapshots.GetSnapshotRequest, dict,])
+@pytest.mark.parametrize(
+    "request_type",
+    [
+        snapshots.GetSnapshotRequest,
+        dict,
+    ],
+)
 def test_get_snapshot(request_type, transport: str = "grpc"):
     client = SnapshotsV1Beta3Client(
-        credentials=ga_credentials.AnonymousCredentials(), transport=transport,
+        credentials=ga_credentials.AnonymousCredentials(),
+        transport=transport,
     )
 
     # Everything is optional in proto3 as far as the runtime is concerned,
@@ -696,7 +715,8 @@ def test_get_snapshot_empty_call():
     # This test is a coverage failsafe to make sure that totally empty calls,
     # i.e. request == None and no flattened fields passed, work.
     client = SnapshotsV1Beta3Client(
-        credentials=ga_credentials.AnonymousCredentials(), transport="grpc",
+        credentials=ga_credentials.AnonymousCredentials(),
+        transport="grpc",
     )
 
     # Mock the actual call within the gRPC stub, and fake the request.
@@ -712,7 +732,8 @@ async def test_get_snapshot_async(
     transport: str = "grpc_asyncio", request_type=snapshots.GetSnapshotRequest
 ):
     client = SnapshotsV1Beta3AsyncClient(
-        credentials=ga_credentials.AnonymousCredentials(), transport=transport,
+        credentials=ga_credentials.AnonymousCredentials(),
+        transport=transport,
     )
 
     # Everything is optional in proto3 as far as the runtime is concerned,
@@ -756,10 +777,80 @@ async def test_get_snapshot_async_from_dict():
     await test_get_snapshot_async(request_type=dict)
 
 
-@pytest.mark.parametrize("request_type", [snapshots.DeleteSnapshotRequest, dict,])
+def test_get_snapshot_field_headers():
+    client = SnapshotsV1Beta3Client(
+        credentials=ga_credentials.AnonymousCredentials(),
+    )
+
+    # Any value that is part of the HTTP/1.1 URI should be sent as
+    # a field header. Set these to a non-empty value.
+    request = snapshots.GetSnapshotRequest()
+
+    request.project_id = "project_id_value"
+    request.location = "location_value"
+    request.snapshot_id = "snapshot_id_value"
+
+    # Mock the actual call within the gRPC stub, and fake the request.
+    with mock.patch.object(type(client.transport.get_snapshot), "__call__") as call:
+        call.return_value = snapshots.Snapshot()
+        client.get_snapshot(request)
+
+        # Establish that the underlying gRPC stub method was called.
+        assert len(call.mock_calls) == 1
+        _, args, _ = call.mock_calls[0]
+        assert args[0] == request
+
+    # Establish that the field header was sent.
+    _, _, kw = call.mock_calls[0]
+    assert (
+        "x-goog-request-params",
+        "project_id=project_id_value&location=location_value&snapshot_id=snapshot_id_value",
+    ) in kw["metadata"]
+
+
+@pytest.mark.asyncio
+async def test_get_snapshot_field_headers_async():
+    client = SnapshotsV1Beta3AsyncClient(
+        credentials=ga_credentials.AnonymousCredentials(),
+    )
+
+    # Any value that is part of the HTTP/1.1 URI should be sent as
+    # a field header. Set these to a non-empty value.
+    request = snapshots.GetSnapshotRequest()
+
+    request.project_id = "project_id_value"
+    request.location = "location_value"
+    request.snapshot_id = "snapshot_id_value"
+
+    # Mock the actual call within the gRPC stub, and fake the request.
+    with mock.patch.object(type(client.transport.get_snapshot), "__call__") as call:
+        call.return_value = grpc_helpers_async.FakeUnaryUnaryCall(snapshots.Snapshot())
+        await client.get_snapshot(request)
+
+        # Establish that the underlying gRPC stub method was called.
+        assert len(call.mock_calls)
+        _, args, _ = call.mock_calls[0]
+        assert args[0] == request
+
+    # Establish that the field header was sent.
+    _, _, kw = call.mock_calls[0]
+    assert (
+        "x-goog-request-params",
+        "project_id=project_id_value&location=location_value&snapshot_id=snapshot_id_value",
+    ) in kw["metadata"]
+
+
+@pytest.mark.parametrize(
+    "request_type",
+    [
+        snapshots.DeleteSnapshotRequest,
+        dict,
+    ],
+)
 def test_delete_snapshot(request_type, transport: str = "grpc"):
     client = SnapshotsV1Beta3Client(
-        credentials=ga_credentials.AnonymousCredentials(), transport=transport,
+        credentials=ga_credentials.AnonymousCredentials(),
+        transport=transport,
     )
 
     # Everything is optional in proto3 as far as the runtime is concerned,
@@ -785,7 +876,8 @@ def test_delete_snapshot_empty_call():
     # This test is a coverage failsafe to make sure that totally empty calls,
     # i.e. request == None and no flattened fields passed, work.
     client = SnapshotsV1Beta3Client(
-        credentials=ga_credentials.AnonymousCredentials(), transport="grpc",
+        credentials=ga_credentials.AnonymousCredentials(),
+        transport="grpc",
     )
 
     # Mock the actual call within the gRPC stub, and fake the request.
@@ -801,7 +893,8 @@ async def test_delete_snapshot_async(
     transport: str = "grpc_asyncio", request_type=snapshots.DeleteSnapshotRequest
 ):
     client = SnapshotsV1Beta3AsyncClient(
-        credentials=ga_credentials.AnonymousCredentials(), transport=transport,
+        credentials=ga_credentials.AnonymousCredentials(),
+        transport=transport,
     )
 
     # Everything is optional in proto3 as far as the runtime is concerned,
@@ -830,10 +923,82 @@ async def test_delete_snapshot_async_from_dict():
     await test_delete_snapshot_async(request_type=dict)
 
 
-@pytest.mark.parametrize("request_type", [snapshots.ListSnapshotsRequest, dict,])
+def test_delete_snapshot_field_headers():
+    client = SnapshotsV1Beta3Client(
+        credentials=ga_credentials.AnonymousCredentials(),
+    )
+
+    # Any value that is part of the HTTP/1.1 URI should be sent as
+    # a field header. Set these to a non-empty value.
+    request = snapshots.DeleteSnapshotRequest()
+
+    request.project_id = "project_id_value"
+    request.location = "location_value"
+    request.snapshot_id = "snapshot_id_value"
+
+    # Mock the actual call within the gRPC stub, and fake the request.
+    with mock.patch.object(type(client.transport.delete_snapshot), "__call__") as call:
+        call.return_value = snapshots.DeleteSnapshotResponse()
+        client.delete_snapshot(request)
+
+        # Establish that the underlying gRPC stub method was called.
+        assert len(call.mock_calls) == 1
+        _, args, _ = call.mock_calls[0]
+        assert args[0] == request
+
+    # Establish that the field header was sent.
+    _, _, kw = call.mock_calls[0]
+    assert (
+        "x-goog-request-params",
+        "project_id=project_id_value&location=location_value&snapshot_id=snapshot_id_value",
+    ) in kw["metadata"]
+
+
+@pytest.mark.asyncio
+async def test_delete_snapshot_field_headers_async():
+    client = SnapshotsV1Beta3AsyncClient(
+        credentials=ga_credentials.AnonymousCredentials(),
+    )
+
+    # Any value that is part of the HTTP/1.1 URI should be sent as
+    # a field header. Set these to a non-empty value.
+    request = snapshots.DeleteSnapshotRequest()
+
+    request.project_id = "project_id_value"
+    request.location = "location_value"
+    request.snapshot_id = "snapshot_id_value"
+
+    # Mock the actual call within the gRPC stub, and fake the request.
+    with mock.patch.object(type(client.transport.delete_snapshot), "__call__") as call:
+        call.return_value = grpc_helpers_async.FakeUnaryUnaryCall(
+            snapshots.DeleteSnapshotResponse()
+        )
+        await client.delete_snapshot(request)
+
+        # Establish that the underlying gRPC stub method was called.
+        assert len(call.mock_calls)
+        _, args, _ = call.mock_calls[0]
+        assert args[0] == request
+
+    # Establish that the field header was sent.
+    _, _, kw = call.mock_calls[0]
+    assert (
+        "x-goog-request-params",
+        "project_id=project_id_value&location=location_value&snapshot_id=snapshot_id_value",
+    ) in kw["metadata"]
+
+
+@pytest.mark.parametrize(
+    "request_type",
+    [
+        snapshots.ListSnapshotsRequest,
+        dict,
+    ],
+)
 def test_list_snapshots(request_type, transport: str = "grpc"):
     client = SnapshotsV1Beta3Client(
-        credentials=ga_credentials.AnonymousCredentials(), transport=transport,
+        credentials=ga_credentials.AnonymousCredentials(),
+        transport=transport,
     )
 
     # Everything is optional in proto3 as far as the runtime is concerned,
@@ -859,7 +1024,8 @@ def test_list_snapshots_empty_call():
     # This test is a coverage failsafe to make sure that totally empty calls,
     # i.e. request == None and no flattened fields passed, work.
     client = SnapshotsV1Beta3Client(
-        credentials=ga_credentials.AnonymousCredentials(), transport="grpc",
+        credentials=ga_credentials.AnonymousCredentials(),
+        transport="grpc",
     )
 
     # Mock the actual call within the gRPC stub, and fake the request.
@@ -875,7 +1041,8 @@ async def test_list_snapshots_async(
     transport: str = "grpc_asyncio", request_type=snapshots.ListSnapshotsRequest
 ):
     client = SnapshotsV1Beta3AsyncClient(
-        credentials=ga_credentials.AnonymousCredentials(), transport=transport,
+        credentials=ga_credentials.AnonymousCredentials(),
+        transport=transport,
     )
 
     # Everything is optional in proto3 as far as the runtime is concerned,
@@ -904,6 +1071,71 @@ async def test_list_snapshots_async_from_dict():
     await test_list_snapshots_async(request_type=dict)
 
 
+def test_list_snapshots_field_headers():
+    client = SnapshotsV1Beta3Client(
+        credentials=ga_credentials.AnonymousCredentials(),
+    )
+
+    # Any value that is part of the HTTP/1.1 URI should be sent as
+    # a field header. Set these to a non-empty value.
+    request = snapshots.ListSnapshotsRequest()
+
+    request.project_id = "project_id_value"
+    request.location = "location_value"
+    request.job_id = "job_id_value"
+
+    # Mock the actual call within the gRPC stub, and fake the request.
+    with mock.patch.object(type(client.transport.list_snapshots), "__call__") as call:
+        call.return_value = snapshots.ListSnapshotsResponse()
+        client.list_snapshots(request)
+
+        # Establish that the underlying gRPC stub method was called.
+        assert len(call.mock_calls) == 1
+        _, args, _ = call.mock_calls[0]
+        assert args[0] == request
+
+    # Establish that the field header was sent.
+    _, _, kw = call.mock_calls[0]
+    assert (
+        "x-goog-request-params",
+        "project_id=project_id_value&location=location_value&job_id=job_id_value",
+    ) in kw["metadata"]
+
+
+@pytest.mark.asyncio
+async def test_list_snapshots_field_headers_async():
+    client = SnapshotsV1Beta3AsyncClient(
+        credentials=ga_credentials.AnonymousCredentials(),
+    )
+
+    # Any value that is part of the HTTP/1.1 URI should be sent as
+    # a field header. Set these to a non-empty value.
+    request = snapshots.ListSnapshotsRequest()
+
+    request.project_id = "project_id_value"
+    request.location = "location_value"
+    request.job_id = "job_id_value"
+
+    # Mock the actual call within the gRPC stub, and fake the request.
+    with mock.patch.object(type(client.transport.list_snapshots), "__call__") as call:
+        call.return_value = grpc_helpers_async.FakeUnaryUnaryCall(
+            snapshots.ListSnapshotsResponse()
+        )
+        await client.list_snapshots(request)
+
+        # Establish that the underlying gRPC stub method was called.
+        assert len(call.mock_calls)
+        _, args, _ = call.mock_calls[0]
+        assert args[0] == request
+
+    # Establish that the field header was sent.
+    _, _, kw = call.mock_calls[0]
+    assert (
+        "x-goog-request-params",
+        "project_id=project_id_value&location=location_value&job_id=job_id_value",
+    ) in kw["metadata"]
+
+
 def test_credentials_transport_error():
     # It is an error to provide credentials and a transport instance.
     transport = transports.SnapshotsV1Beta3GrpcTransport(
@@ -911,7 +1143,8 @@ def test_credentials_transport_error():
     )
     with pytest.raises(ValueError):
         client = SnapshotsV1Beta3Client(
-            credentials=ga_credentials.AnonymousCredentials(), transport=transport,
+            credentials=ga_credentials.AnonymousCredentials(),
+            transport=transport,
         )
 
     # It is an error to provide a credentials file and a transport instance.
@@ -931,7 +1164,10 @@ def test_credentials_transport_error():
     options = client_options.ClientOptions()
     options.api_key = "api_key"
     with pytest.raises(ValueError):
-        client = SnapshotsV1Beta3Client(client_options=options, transport=transport,)
+        client = SnapshotsV1Beta3Client(
+            client_options=options,
+            transport=transport,
+        )
 
     # It is an error to provide an api_key and a credential.
     options = mock.Mock()
@@ -947,7 +1183,8 @@ def test_credentials_transport_error():
     )
     with pytest.raises(ValueError):
         client = SnapshotsV1Beta3Client(
-            client_options={"scopes": ["1", "2"]}, transport=transport,
+            client_options={"scopes": ["1", "2"]},
+            transport=transport,
         )
 
 
@@ -990,10 +1227,28 @@ def test_transport_adc(transport_class):
         adc.assert_called_once()
 
 
+@pytest.mark.parametrize(
+    "transport_name",
+    [
+        "grpc",
+    ],
+)
+def test_transport_kind(transport_name):
+    transport = SnapshotsV1Beta3Client.get_transport_class(transport_name)(
+        credentials=ga_credentials.AnonymousCredentials(),
+    )
+    assert transport.kind == transport_name
+
+
 def test_transport_grpc_default():
     # A client should use the gRPC transport by default.
-    client = SnapshotsV1Beta3Client(credentials=ga_credentials.AnonymousCredentials(),)
-    assert isinstance(client.transport, transports.SnapshotsV1Beta3GrpcTransport,)
+    client = SnapshotsV1Beta3Client(
+        credentials=ga_credentials.AnonymousCredentials(),
+    )
+    assert isinstance(
+        client.transport,
+        transports.SnapshotsV1Beta3GrpcTransport,
+    )
 
 
 def test_snapshots_v1_beta3_base_transport_error():
@@ -1029,6 +1284,14 @@ def test_snapshots_v1_beta3_base_transport():
     with pytest.raises(NotImplementedError):
         transport.close()
 
+    # Catch all for all remaining methods and properties
+    remainder = [
+        "kind",
+    ]
+    for r in remainder:
+        with pytest.raises(NotImplementedError):
+            getattr(transport, r)()
+
 
 def test_snapshots_v1_beta3_base_transport_with_credentials_file():
     # Instantiate the base transport with a credentials file
@@ -1040,7 +1303,8 @@ def test_snapshots_v1_beta3_base_transport_with_credentials_file():
         Transport.return_value = None
         load_creds.return_value = (ga_credentials.AnonymousCredentials(), None)
         transport = transports.SnapshotsV1Beta3Transport(
-            credentials_file="credentials.json", quota_project_id="octopus",
+            credentials_file="credentials.json",
+            quota_project_id="octopus",
         )
         load_creds.assert_called_once_with(
             "credentials.json",
@@ -1193,24 +1457,40 @@ def test_snapshots_v1_beta3_grpc_transport_client_cert_source_for_mtls(transport
             )
 
 
-def test_snapshots_v1_beta3_host_no_port():
+@pytest.mark.parametrize(
+    "transport_name",
+    [
+        "grpc",
+        "grpc_asyncio",
+    ],
+)
+def test_snapshots_v1_beta3_host_no_port(transport_name):
     client = SnapshotsV1Beta3Client(
         credentials=ga_credentials.AnonymousCredentials(),
         client_options=client_options.ClientOptions(
             api_endpoint="dataflow.googleapis.com"
         ),
+        transport=transport_name,
     )
-    assert client.transport._host == "dataflow.googleapis.com:443"
+    assert client.transport._host == ("dataflow.googleapis.com:443")
 
 
-def test_snapshots_v1_beta3_host_with_port():
+@pytest.mark.parametrize(
+    "transport_name",
+    [
+        "grpc",
+        "grpc_asyncio",
+    ],
+)
+def test_snapshots_v1_beta3_host_with_port(transport_name):
     client = SnapshotsV1Beta3Client(
         credentials=ga_credentials.AnonymousCredentials(),
         client_options=client_options.ClientOptions(
             api_endpoint="dataflow.googleapis.com:8000"
         ),
+        transport=transport_name,
     )
-    assert client.transport._host == "dataflow.googleapis.com:8000"
+    assert client.transport._host == ("dataflow.googleapis.com:8000")
 
 
 def test_snapshots_v1_beta3_grpc_transport_channel():
@@ -1218,7 +1498,8 @@ def test_snapshots_v1_beta3_grpc_transport_channel():
 
     # Check that channel is used if provided.
     transport = transports.SnapshotsV1Beta3GrpcTransport(
-        host="squid.clam.whelk", channel=channel,
+        host="squid.clam.whelk",
+        channel=channel,
     )
     assert transport.grpc_channel == channel
     assert transport._host == "squid.clam.whelk:443"
@@ -1230,7 +1511,8 @@ def test_snapshots_v1_beta3_grpc_asyncio_transport_channel():
 
     # Check that channel is used if provided.
     transport = transports.SnapshotsV1Beta3GrpcAsyncIOTransport(
-        host="squid.clam.whelk", channel=channel,
+        host="squid.clam.whelk",
+        channel=channel,
     )
     assert transport.grpc_channel == channel
     assert transport._host == "squid.clam.whelk:443"
@@ -1359,7 +1641,9 @@ def test_parse_common_billing_account_path():
 
 def test_common_folder_path():
     folder = "whelk"
-    expected = "folders/{folder}".format(folder=folder,)
+    expected = "folders/{folder}".format(
+        folder=folder,
+    )
     actual = SnapshotsV1Beta3Client.common_folder_path(folder)
     assert expected == actual
 
@@ -1377,7 +1661,9 @@ def test_parse_common_folder_path():
 
 def test_common_organization_path():
     organization = "oyster"
-    expected = "organizations/{organization}".format(organization=organization,)
+    expected = "organizations/{organization}".format(
+        organization=organization,
+    )
     actual = SnapshotsV1Beta3Client.common_organization_path(organization)
     assert expected == actual
 
@@ -1395,7 +1681,9 @@ def test_parse_common_organization_path():
 
 def test_common_project_path():
     project = "cuttlefish"
-    expected = "projects/{project}".format(project=project,)
+    expected = "projects/{project}".format(
+        project=project,
+    )
     actual = SnapshotsV1Beta3Client.common_project_path(project)
     assert expected == actual
 
@@ -1415,7 +1703,8 @@ def test_common_location_path():
     project = "winkle"
     location = "nautilus"
     expected = "projects/{project}/locations/{location}".format(
-        project=project, location=location,
+        project=project,
+        location=location,
     )
     actual = SnapshotsV1Beta3Client.common_location_path(project, location)
     assert expected == actual
@@ -1440,7 +1729,8 @@ def test_client_with_default_client_info():
         transports.SnapshotsV1Beta3Transport, "_prep_wrapped_messages"
     ) as prep:
         client = SnapshotsV1Beta3Client(
-            credentials=ga_credentials.AnonymousCredentials(), client_info=client_info,
+            credentials=ga_credentials.AnonymousCredentials(),
+            client_info=client_info,
         )
         prep.assert_called_once_with(client_info)
 
@@ -1449,7 +1739,8 @@ def test_client_with_default_client_info():
     ) as prep:
         transport_class = SnapshotsV1Beta3Client.get_transport_class()
         transport = transport_class(
-            credentials=ga_credentials.AnonymousCredentials(), client_info=client_info,
+            credentials=ga_credentials.AnonymousCredentials(),
+            client_info=client_info,
         )
         prep.assert_called_once_with(client_info)
 
@@ -1457,7 +1748,8 @@ def test_client_with_default_client_info():
 @pytest.mark.asyncio
 async def test_transport_close_async():
     client = SnapshotsV1Beta3AsyncClient(
-        credentials=ga_credentials.AnonymousCredentials(), transport="grpc_asyncio",
+        credentials=ga_credentials.AnonymousCredentials(),
+        transport="grpc_asyncio",
     )
     with mock.patch.object(
         type(getattr(client.transport, "grpc_channel")), "close"
